diff artifacts/src/main/java/org/dive4elements/river/artifacts/services/ThemeListingService.java @ 8202:e4606eae8ea5

sed src/**/*.java 's/logger/log/g'
author Sascha L. Teichmann <teichmann@intevation.de>
date Fri, 05 Sep 2014 12:58:17 +0200
parents af13ceeba52a
children 0a5239a1e46e
line wrap: on
line diff
--- a/artifacts/src/main/java/org/dive4elements/river/artifacts/services/ThemeListingService.java	Fri Sep 05 12:54:58 2014 +0200
+++ b/artifacts/src/main/java/org/dive4elements/river/artifacts/services/ThemeListingService.java	Fri Sep 05 12:58:17 2014 +0200
@@ -34,8 +34,8 @@
  */
 public class ThemeListingService extends D4EService {
 
-    /** The logger used in this service.*/
-    private static Logger logger = Logger.getLogger(ThemeListingService.class);
+    /** The log used in this service.*/
+    private static Logger log = Logger.getLogger(ThemeListingService.class);
 
     private static final String XPATH_THEME_NAME = "/theme/@name";
 
@@ -44,11 +44,11 @@
         GlobalContext context,
         CallMeta      callMeta
     ) {
-        logger.debug("ThemeListingService.process");
+        log.debug("ThemeListingService.process");
         String name = XMLUtils.xpathString(data, XPATH_THEME_NAME, null);
 
         if (name == null) {
-            logger.warn("No theme name provided.");
+            log.warn("No theme name provided.");
         }
         Document result = XMLUtils.newDocument();
 

http://dive4elements.wald.intevation.org